API — Translate Toolkit 1.11.0 documentation

# API

The Translate Toolkit provides several modules for programmers to build their own tools.

## Module overview

The following will give you an idea about what each module is capable of.

### convert

Code to convert between different storage formats for localizations.

### filters

Filters that can be used on translations...

### lang

Classes that represent languages and provides language-specific information.

All classes inherit from the parent class called `common`.

The type of data includes:

- Language codes
- Language name
- Plurals
- Punctuation transformation
- etc.

### misc

Miscellaneous modules for translate - including modules for backward compatibility with pre-2.3 versions of Python

### search

Services for searching and matching of text.

### services

translate.services is part of the translate toolkit. It provides network services for interacting with the toolkit

### storage

Classes that represent various storage formats for localization.

### tools

Code to perform various operations, mostly on po files.

## Module list

All the modules included in the Translated Toolkit are listed here.

- convert
  - acesskey
  - convert
  - csv2po
  - csv2tbx
  - dtd2po
  - factory
  - html2po
  - ical2po
  - ini2po
  - json2po
  - moz2po
  - mozfunny2prop
  - mozlang2po
  - odf2xliff
  - oo2po
  - oo2xliff
  - php2po
  - po2csv
  - po2dtd
  - po2html
  - po2ical
  - po2ini
  - po2json
  - po2mozlang
  - po2moz
  - po2oo
  - po2php
  - po2prop
  - po2rc
  - po2sub
  - po2symb
  - po2tiki
  - po2tmx
  - po2ts
  - po2txt
  - po2web2py
  - po2wordfast
  - po2xliff
  - poreplace
  - pot2po
  - prop2mozfunny
  - prop2po
  - rc2po
  - sub2po
  - symb2po
  - tiki2po
  - ts2po
  - txt2po
  - web2py2po
  - xliff2odf
  - xliff2oo
  - xliff2po
- filters
  - autocorrect
  - checks
  - decoration
  - helpers
  - pofilter
  - prefilters
  - spelling
- lang
  - af
  - am
  - ar
  - bn
  - code_or
  - common
  - data
  - de
  - el
  - es
  - factory
  - fa
  - fi
  - fr
  - gu
  - he
  - hi
  - hy
  - identify
  - ja
  - km
  - kn
  - ko
  - ml
  - mr
  - ne
  - ngram
  - pa
  - poedit
  - si
  - st
  - sv
  - ta
  - team
  - te
  - th
  - ug
  - ur
  - vi
  - zh
- misc
  - autoencode
  - contextlib
  - context
  - dictutils
  - diff_match_patch
  - file_discovery
  - hash
  - ini
  - lru
  - multistring
  - optrecurse
  - ourdom
  - profiling
  - progressbar
  - quote
  - sparse
  - stdiotell
  - textwrap
  - typecheck
    - doctest_support
    - mixins
    - sets
    - typeclasses
  - wsgi
  - wStringIO
  - xml_helpers
  - xmlwrapper
- search
  - indexing
    - CommonIndexer
    - PyLuceneIndexer1
    - PyLuceneIndexer
    - XapianIndexer
  - lshtein
  - match
  - segment
  - terminology
- services
  - tmserver
- storage
  - base
  - benchmark
  - bundleprojstore
  - catkeys
  - cpo
  - csvl10n
  - directory
  - dtd
  - _factory_classes
  - factory
  - fpo
  - html
  - ical
  - ini
  - jsonl10n
  - lisa
  - mo
  - mozilla_lang
  - odf_io
  - odf_shared
  - omegat
  - oo
  - placeables
    - base
    - general
    - interfaces
    - lisa
    - parse
    - strelem
    - terminology
    - xliff
  - php
  - pocommon
  - poheader
  - poparser
  - po
  - poxliff
  - project
  - projstore
  - properties
  - pypo
  - qm
  - qph
  - rc
  - statistics
  - statsdb
  - subtitles
  - symbian
  - tbx
  - tiki
  - tmdb
  - tmx
  - trados
  - ts2
  - ts
  - txt
  - utx
  - versioncontrol
    - bzr
    - cvs
    - darcs
    - git
    - hg
    - svn
  - wordfast
  - workflow
  - xliff
  - xml_extract
    - extract
    - generate
    - misc
    - unit_tree
    - xpath_breadcrumb
  - xml_name
  - zip
- tools
  - build_tmdb
  - phppo2pypo
  - poclean
  - pocompile
  - poconflicts
  - pocount
  - podebug
  - pogrep
  - pomerge
  - porestructure
  - posegment
  - poswap
  - poterminology
  - pretranslate
  - pydiff
  - pypo2phppo